### Title: myFirstRScript ----
# (c) 2018 Ben Anderson (@dataknut)
# Original code: 

# Helpful documentation:
# https://www.rdocumentation.org/
# https://www.statmethods.net/index.html
# https://stackoverflow.com/questions/tagged/r

# Print out the date - always useful to know
Sys.Date()

# Print out the time - also useful to know
Sys.time()

# Do some simple maths
4 + 4

# Do some simple maths and capture the result
result <- 4 + 4 # we could have used = but Rgonauts prefer <- as it means _assignment_ not 'equal to' - see https://www.rdocumentation.org/packages/base/versions/3.4.3/topics/assignOps

# Tell us the result!
result

# Do something to the result and print the answer
sqrt(result)

# Create a data.table - these are similar to data frames which are built in to R (both can be conceived as 'spreadsheets' or 'tables') but much faster & more memory efficient, so they're good for Big Data (tm)
# Before we create a data table we have to load the data.table library as it is not a core part of R ('base')
library(data.table)

# OK, now we're ready
# Create a new data table with one column called 'index' and n rows defined by.... nRows
nRows <- 100
dt <- data.table(index = rep(1:nRows))

# check what it looks like
dt

# now do something to each row of index
dt <- dt[, sqrtIndex := sqrt(index)] # NB: we didn't need to do the <- assignment because data.table will update it's contents but we'll stick with assignment for now to ease the cognitive load!

# check what it looks like - there should now be two columns.
dt

# that was a lot of rows, try looking at just the top 6 (default)
head(dt)

# Or perhaps specifically the top 10 rows
head(dt, 10)

# Or perhaps the top 10 rows after we sort in descending order by sqrtIndex
head(dt[order(-sqrtIndex)], 10)

# Or maybe we'd like some summary statistics
summary(dt)

# But we'd quite like to visualise the data - draw a simple plot
plot(dt)

# Or maybe we'd like to test a correlation
cor.test(dt$index, dt$sqrtIndex)

# Did you get bored typing dt twice?
with(dt, cor.test(index, sqrtIndex)) # use with() to tell R which object (usually a data.table) you want to work with. In this case it made for more typing but if your object name is long or you need to type a lot of variables it will save on finger-wear

# Now let's try a very simple linear regression model and catch the results in a model result object
# Bonus points for telling me why a linear model is the _wrong_ choice!
linearModelResult <- lm(index ~ sqrtIndex, dt)

summary(linearModelResult) # note we use 'summary' again but it knows what to with a model result object
